@@ -19,6 +19,19 @@
 //! As Rust strings are UTF-8 encoded, the algorithm for finding a character substring is `O(n)`,
 //! where `n` is the byte length of the string. This is due to characters not being of predictible
 //! byte lengths.
+//!
+//! # Note
+//! The indexing of substrings is based on Unicode Scalar Value. As such, substrings may not always
+//! match your intuition:
+//!
+//! ```
+//! use substring::Substring;
+//!
+//! assert_eq!("y̆".substring(0, 1), "y");  // As opposed to "y̆".
+//! assert_eq!("y̆".substring(1, 2), "\u{0306}")  // The diacritical mark counts as its own character.
+//! ```
+//!
+//! The above example occurs because "y̆"" is technically made up of two UTF-8 scalar values.
 
 /// Provides a `substring` method.
 ///
@@ -49,11 +62,19 @@ impl Substring for str {
         if end_index <= start_index {
             return "";
         }
-        
+
         let mut indices = self.char_indices();
-        let (start_byte, _start_char) = indices.nth(start_index).unwrap_or((self.len(), ' '));
-        let (end_byte, _end_char) = indices.nth(end_index - start_index - 1).unwrap_or((self.len(), ' '));
-        &self[start_byte..end_byte]
+
+        let obtain_index = |(index, _char)| index;
+
+        &self[indices
+            .nth(start_index)
+            .map(&obtain_index)
+            .unwrap_or(self.len())
+            ..indices
+                .nth(end_index - start_index - 1)
+                .map(&obtain_index)
+                .unwrap_or(self.len())]
     }
 }
 
@@ -81,7 +102,7 @@ mod tests {
     fn test_start_and_end_equal() {
         assert_eq!("foobar".substring(3, 3), "");
     }
-    
+
     #[test]
     fn test_multiple_byte_characters() {
         assert_eq!("fõøbα®".substring(2, 5), "øbα");
